API Reference
=============

This is the auto-generated API reference for Pidgin's Python modules.

Core Modules
------------

.. automodule:: pidgin.core.conductor
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.core.types
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.core.event_bus
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.core.events
   :members:
   :undoc-members:
   :show-inheritance:

Provider Modules
----------------

.. automodule:: pidgin.providers.base
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.providers.builder
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.providers.openai_provider
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.providers.anthropic
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.providers.google
   :members:
   :undoc-members:
   :show-inheritance:

Metrics Modules
---------------

.. automodule:: pidgin.metrics.flat_calculator
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.metrics.convergence_metrics
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.metrics.linguistic_metrics
   :members:
   :undoc-members:
   :show-inheritance:

Database Modules
----------------

.. automodule:: pidgin.database.import_service
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.database.event_store
   :members:
   :undoc-members:
   :show-inheritance:

Experiment Modules
------------------

.. automodule:: pidgin.experiments.runner
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.experiments.manager
   :members:
   :undoc-members:
   :show-inheritance:

Analysis Modules
----------------

.. automodule:: pidgin.analysis.notebook_generator
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: pidgin.analysis.convergence
   :members:
   :undoc-members:
   :show-inheritance: